﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using Html5Representor.Models;

namespace Html5Representor
{
    public class StockatoWSHelper
    {
        public const string ExpenseRatio = " Expense Ratio: ";
        public const string FiveYearAvgReturn = " 5y Avg Return: ";
        public const string Beta3Year = " Beta (3y): ";
        public const string MorningstarRating = " Morningstar Rating: ";
        public const string ThreeYearAvgReturn = " 3y Avg Return: ";

        public static BehaviorBasedSearchVM GetInstrumentFromStringValue(string instrumentStr,
                                                                         int? symbolOfInterestMorningstarRating,
                                                                         double? symbolOfInterestBeta,
                                                                         double? symbolOfInterestExpenseRatio,
                                                                         double? symbolOfInterest3YearsAveReturn,
                                                                         double? symbolOfInterest5YearsAveReturn)
        {
            BehaviorBasedSearchVM model = null;

            if (!string.IsNullOrWhiteSpace(instrumentStr))
            {
                model = new BehaviorBasedSearchVM();
                model.ValuePairs = new Dictionary<string, string>();
                model.HighlightValues = new List<string>();

                char[] fourPartDelimiterChars = { '$', '#', '!' };
                string[] fourPartResult = instrumentStr.Split(fourPartDelimiterChars);
                model.Symbol = fourPartResult[0];
                model.Description = fourPartResult[1];
                model.StockExchangeText = fourPartResult[2];

                string[] details = fourPartResult[3].Split(',');

                foreach (var item in details)
                {
                    string[] valuePair = item.Split(':');

                    if (valuePair.Length == 2 && valuePair[1] != "NaN%" && valuePair[1] != "N/A")
                    {
                        if (string.Equals(valuePair[0], "Total Assets", System.StringComparison.OrdinalIgnoreCase))
                        {
                            model.ValuePairs.Add(" Total Assets: ", valuePair[1]);
                        }
                        else if (string.Equals(valuePair[0], "Category", System.StringComparison.OrdinalIgnoreCase))
                        {
                            model.ValuePairs.Add(" Category: ", valuePair[1]);
                        }
                        else if (string.Equals(valuePair[0], "Annual Report Expense Ratio (net)", System.StringComparison.OrdinalIgnoreCase))
                        {
                            model.ValuePairs.Add(ExpenseRatio, valuePair[1]);

                            if (symbolOfInterestExpenseRatio.HasValue &&
                                Convert.ToDouble(valuePair[1].Replace("%", "")) < symbolOfInterestExpenseRatio)
                            {
                                model.HighlightValues.Add("Lower Expense Ratio");
                            }
                        }
                        else if (string.Equals(valuePair[0], "5y Avg Return", System.StringComparison.OrdinalIgnoreCase))
                        {
                            model.ValuePairs.Add(FiveYearAvgReturn, valuePair[1]);

                            if (symbolOfInterest5YearsAveReturn.HasValue &&
                                Convert.ToDouble(valuePair[1].Replace("%", "")) > symbolOfInterest5YearsAveReturn)
                            {
                                model.HighlightValues.Add("Higher 5Y Avg Return");
                            }
                        }
                        else if (string.Equals(valuePair[0], "Beta (3y)", System.StringComparison.OrdinalIgnoreCase))
                        {
                            model.ValuePairs.Add(Beta3Year, valuePair[1]);

                            if (symbolOfInterestBeta.HasValue &&
                                Convert.ToDouble(valuePair[1]) < symbolOfInterestBeta)
                            {
                                model.HighlightValues.Add("Lower Beta");
                            }
                        }
                        else if (string.Equals(valuePair[0], "Morningstar Risk Rating", System.StringComparison.OrdinalIgnoreCase))
                        {
                            model.ValuePairs.Add(MorningstarRating, valuePair[1]);

                            if (symbolOfInterestMorningstarRating.HasValue &&
                                Convert.ToInt32(valuePair[1]) > symbolOfInterestMorningstarRating)
                            {
                                model.HighlightValues.Add("Higher Morningstar Rating");
                            }
                        }
                        else if (string.Equals(valuePair[0], "3y Avg Return", System.StringComparison.OrdinalIgnoreCase))
                        {
                            model.ValuePairs.Add(ThreeYearAvgReturn, valuePair[1]);

                            if (symbolOfInterest3YearsAveReturn.HasValue &&
                                Convert.ToDouble(valuePair[1].Replace("%", "")) > symbolOfInterest3YearsAveReturn)
                            {
                                model.HighlightValues.Add("Higher 3Y Avg Return");
                            }
                        }
                        else
                        {
                            Trace.TraceWarning("Notsupported value pair: '{0}'", item);
                        }
                    }
                    else
                    {
                        Trace.TraceWarning("Bad value pair: '{0}'", item);
                    }
                }
            }

            return model;
        }

        public static List<BehaviorBasedSearchVM> GetInstrumentsFromStringValue(ICollection<string> instrumentList)
        {
            List<BehaviorBasedSearchVM> resultList = new List<BehaviorBasedSearchVM>();

            int? symbolOfInterestMorningstarRating = null;
            double? symbolOfInterestBeta = null;
            double? symbolOfInterestExpenseRatio = null;
            double? symbolOfInterest3YearsAveReturn = null;
            double? symbolOfInterest5YearsAveReturn = null;

            if (instrumentList != null && instrumentList.Count > 1)
            {
                foreach (var instrumentStr in instrumentList)
                {
                    var result = GetInstrumentFromStringValue(instrumentStr,
                                                              symbolOfInterestMorningstarRating,
                                                              symbolOfInterestBeta,
                                                              symbolOfInterestExpenseRatio,
                                                              symbolOfInterest3YearsAveReturn,
                                                              symbolOfInterest5YearsAveReturn);
       
                    resultList.Add(result);

                    if (resultList.Count == 1)
                    {
                        if (result.ValuePairs.ContainsKey(MorningstarRating))
                            symbolOfInterestMorningstarRating = Convert.ToInt32(result.ValuePairs[MorningstarRating]);

                        if (result.ValuePairs.ContainsKey(Beta3Year))
                            symbolOfInterestBeta = Convert.ToDouble(result.ValuePairs[Beta3Year].Replace("%", ""));

                        if (result.ValuePairs.ContainsKey(ExpenseRatio))
                            symbolOfInterestExpenseRatio = Convert.ToDouble(result.ValuePairs[ExpenseRatio].Replace("%", ""));

                        if (result.ValuePairs.ContainsKey(ThreeYearAvgReturn))
                            symbolOfInterest3YearsAveReturn = Convert.ToDouble(result.ValuePairs[ThreeYearAvgReturn].Replace("%", ""));

                        if (result.ValuePairs.ContainsKey(FiveYearAvgReturn))
                            symbolOfInterest5YearsAveReturn = Convert.ToDouble(result.ValuePairs[FiveYearAvgReturn].Replace("%", ""));
                    }
                }
            }

            return resultList;
        }
    }
}